LVCopy

Trait LVCopy 

pub trait LVCopy { }
A trait which defines that a type should be copyable inside of a LabVIEW handle.

This is unique from Copy since unsized types can be inside a handle but they can’t implement Copy.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl LVCopy for LStr

Copyable inside a handle.

Source

impl<T: Copy> LVCopy for T

Rust copy types should be copyable in LabVIEW.

Source

impl<const D: usize, T> LVCopy for LVArray<D, T>