pub struct LVUserEvent<T> { /* private fields */ }Expand description
Representation of a LabVIEW user event reference with type data.
Where the reference is passed into Rust you can use this typed form to then allow proper type completions of the values.
From LabVIEW you can set the terminal to be adapt to type and handles by value
Example
#[no_mangle]
pub extern "C" fn generate_event_3(lv_user_event: *mut LVUserEvent<i32>) -> LVStatusCode {
let event = unsafe { *lv_user_event };
let result = event.post(&mut 3);
match result {
Ok(_) => LVStatusCode::SUCCESS,
Err(err) => err.into(),
}
}Implementations