pub trait LVCopy { }Expand description
A trait which defines that a type should be copyable inside of a LabVIEW handle.
This is unique from Copy since unsized types can be inside a handle
but they can’t implement Copy.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".